<%inherit file="../base/base.html" /> <%namespace file="../base/base.html" import="header, setup_margin_labels" /> <%block name="extra_meta"> ${ setup_margin_labels(title) }
${ header(complete_header, title, report.get_subtitle(), notes) } <%include file="sale-details.html" /> <%include file="sale-items.html" /> <%include file="../base/payment-list.html" args="payments=report.order.payments" /> <%include file="sale-notes.html" />